@@ -1,14 +1,17 @@
-#  Copyright (c) 2020 zfit
+#  Copyright (c) 2021 zfit
 
 from .core.basepdf import BasePDF
 from .models.basic import Exponential
-from .models.dist_tfp import Gauss, Uniform, WrapDistribution, TruncatedGauss, Cauchy, Poisson
-from .models.functor import ProductPDF, SumPDF, BaseFunctor
+from .models.conditional import ConditionalPDFV1
+from .models.convolution import FFTConvPDFV1
+from .models.dist_tfp import (Cauchy, Gauss, Poisson, TruncatedGauss, Uniform,
+                              WrapDistribution)
+from .models.functor import BaseFunctor, ProductPDF, SumPDF
 from .models.kde import GaussianKDE1DimV1
 from .models.physics import CrystalBall, DoubleCB
-from .models.polynomials import Chebyshev, Legendre, Chebyshev2, Hermite, Laguerre, RecursivePolynomial
-from .models.special import ZPDF, SimplePDF, SimpleFunctorPDF
-from .models.convolution import FFTConvPDFV1
+from .models.polynomials import (Chebyshev, Chebyshev2, Hermite, Laguerre,
+                                 Legendre, RecursivePolynomial)
+from .models.special import ZPDF, SimpleFunctorPDF, SimplePDF
 
 __all__ = ['BasePDF', 'BaseFunctor',
            'Exponential',
@@ -18,5 +21,6 @@ __all__ = ['BasePDF', 'BaseFunctor',
            'ProductPDF', 'SumPDF',
            'GaussianKDE1DimV1',
            'FFTConvPDFV1',
+           'ConditionalPDFV1',
            'ZPDF', 'SimplePDF', 'SimpleFunctorPDF'
            ]
